@@ -55,17 +55,13 @@ class Config:
         self.components.append(component)
         return self.components.index(self.components[-1])
 
-    def components_to_dict(self) -> Dict[str, components.TDictComponent]:
-        return {
-            component.component_name: component.to_dict()
-            for component in self.components
-        }
-
     def save_to_yaml(self, file: Optional[str] = None) -> None:
         path = file or self.config_file
         if path:
             file_to_save: Path = Path(path)
-            yaml.dump(self.components_to_dict(), open(file_to_save, "w"))
+            yaml.dump(
+                Component.components_to_dict(self.components), open(file_to_save, "w")
+            )
         else:
             logger.error(
                 f"No config file provided and no config file found in project directory."
@@ -87,7 +83,11 @@ class Config:
                 self.save_to_yaml()
 
         if print_yaml:
-            click.echo(pprint.pformat(yaml.dump(self.components_to_dict()), indent=4))
+            click.echo(
+                pprint.pformat(
+                    yaml.dump(Component.components_to_dict(self.components)), indent=4
+                )
+            )
 
     def read_from_yaml(self, file: Optional[Path] = None) -> None:
         read_file = file or self.config_file
@@ -117,6 +117,9 @@ class Config:
             comp.version_pattern = compd.get(
                 "version-pattern", comp.DEFAULT_VERSION_PATTERN
             )
+            comp.files_version_pattern = compd.get(
+                "files-version-pattern", comp.DEFAULT_FILES_VERSION_PATTERN
+            )
 
     def add_from_requirements(self, req_file: str, req_source: str) -> None:
 
@@ -199,6 +202,7 @@ class Config:
                 )
 
     def update_files(self, dry_run: bool = False) -> Tuple[int, int]:
+        """Update all files for all components. Return number of updated components and number of files updated."""
         file_counter = 0
         components_counter = 0
         for component in self.components:
